@@ -2,7 +2,7 @@
 This module contains all constants representing the frequency of an :class:`~integreat_cms.cms.models.events.event.Event`'s
 :class:`~integreat_cms.cms.models.events.recurrence_rule.RecurrenceRule`.
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 #: Daily
