@@ -1,7 +1,7 @@
 """
 This module contains the states a translation can have
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 #: Up to date
 UP_TO_DATE = "UP_TO_DATE"
