@@ -1,7 +1,7 @@
 """
 This module contains all string representations of weekdays, used by :class:`~integreat_cms.cms.models.events.event.Event`.
 """
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 #: Monday
@@ -29,3 +29,9 @@ CHOICES = (
     (SATURDAY, _("Saturday")),
     (SUNDAY, _("Sunday")),
 )
+
+#: Working days: Monday to Friday
+WORKING_DAYS = [MONDAY, TUESDAY, WEDNESDAY, THURSDAY, FRIDAY]
+
+#: Weekend: Saturday and Sunday
+WEEKEND = [SATURDAY, SUNDAY]
